@@ -1,26 +1,36 @@
 import ast
 import importlib
 import logging
+import logging.config
 import os
 import sys
 from typing import Dict, Any  # noqa: F401
+from flask_cors import CORS
 
+from flasgger import Swagger
 from flask import Flask, Blueprint
 from flask_restful import Api
 
 from metadata_service.api.column import ColumnDescriptionAPI
+from metadata_service.api.dashboard import DashboardDetailAPI, DashboardDescriptionAPI, DashboardTagAPI
 from metadata_service.api.healthcheck import healthcheck
 from metadata_service.api.popular_tables import PopularTablesAPI
 from metadata_service.api.system import Neo4jDetailAPI
 from metadata_service.api.table \
     import TableDetailAPI, TableOwnerAPI, TableTagAPI, TableDescriptionAPI
 from metadata_service.api.tag import TagAPI
-from metadata_service.api.user import UserDetailAPI, UserFollowAPI, UserOwnAPI, UserReadAPI
+from metadata_service.api.user import (UserDetailAPI, UserFollowAPI,
+                                       UserFollowsAPI, UserOwnsAPI,
+                                       UserOwnAPI, UserReadsAPI)
 
 # For customized flask use below arguments to override.
 FLASK_APP_MODULE_NAME = os.getenv('FLASK_APP_MODULE_NAME')
 FLASK_APP_CLASS_NAME = os.getenv('FLASK_APP_CLASS_NAME')
 FLASK_APP_KWARGS_DICT_STR = os.getenv('FLASK_APP_KWARGS_DICT')
+ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
+
+# Environment Variable to enable cors
+CORS_ENABLED = os.environ.get('CORS_ENABLED', False)
 
 
 def create_app(*, config_module_class: str) -> Flask:
@@ -54,12 +64,17 @@ def create_app(*, config_module_class: str) -> Flask:
     else:
         app = Flask(__name__)
 
+    if CORS_ENABLED:
+        CORS(app)
     config_module_class = \
         os.getenv('METADATA_SVC_CONFIG_MODULE_CLASS') or config_module_class
     app.config.from_object(config_module_class)
 
-    logging.basicConfig(format=app.config.get('LOG_FORMAT'), datefmt=app.config.get('LOG_DATE_FORMAT'))
-    logging.getLogger().setLevel(app.config.get('LOG_LEVEL'))
+    if app.config.get('LOG_CONFIG_FILE'):
+        logging.config.fileConfig(app.config.get('LOG_CONFIG_FILE'), disable_existing_loggers=False)
+    else:
+        logging.basicConfig(format=app.config.get('LOG_FORMAT'), datefmt=app.config.get('LOG_DATE_FORMAT'))
+        logging.getLogger().setLevel(app.config.get('LOG_LEVEL'))
     logging.info('Created app with config name {}'.format(config_module_class))
     logging.info('Using backend {}'.format(app.config.get('PROXY_CLIENT')))
 
@@ -71,31 +86,38 @@ def create_app(*, config_module_class: str) -> Flask:
     api.add_resource(PopularTablesAPI, '/popular_tables/')
     api.add_resource(TableDetailAPI, '/table/<path:table_uri>')
     api.add_resource(TableDescriptionAPI,
-                     '/table/<path:table_uri>/description',
-                     '/table/<path:table_uri>/description/<path:description_val>')
+                     '/table/<path:id>/description')
     api.add_resource(TableTagAPI,
-                     '/table/<path:table_uri>/tag',
-                     '/table/<path:table_uri>/tag/<tag>')
+                     '/table/<path:id>/tag/<tag>')
     api.add_resource(TableOwnerAPI,
                      '/table/<path:table_uri>/owner/<owner>')
     api.add_resource(ColumnDescriptionAPI,
-                     '/table/<path:table_uri>/column/<column_name>/description',
-                     '/table/<path:table_uri>/column/<column_name>/description/<path:description_val>')
+                     '/table/<path:table_uri>/column/<column_name>/description')
     api.add_resource(Neo4jDetailAPI,
                      '/latest_updated_ts')
     api.add_resource(TagAPI,
                      '/tags/')
     api.add_resource(UserDetailAPI,
-                     '/user/<path:user_id>')
+                     '/user',
+                     '/user/<path:id>')
+    api.add_resource(UserFollowsAPI,
+                     '/user/<path:user_id>/follow/')
     api.add_resource(UserFollowAPI,
-                     '/user/<path:user_id>/follow/',
-                     '/user/<path:user_id>/follow/<resource_type>/<path:table_uri>')
+                     '/user/<path:user_id>/follow/<resource_type>/<path:resource_id>')
+    api.add_resource(UserOwnsAPI,
+                     '/user/<path:user_id>/own/')
     api.add_resource(UserOwnAPI,
-                     '/user/<path:user_id>/own/',
                      '/user/<path:user_id>/own/<resource_type>/<path:table_uri>')
-    api.add_resource(UserReadAPI,
-                     '/user/<path:user_id>/read/',
-                     '/user/<path:user_id>/read/<resource_type>/<path:table_uri>')
+    api.add_resource(UserReadsAPI,
+                     '/user/<path:user_id>/read/')
+    api.add_resource(DashboardDetailAPI,
+                     '/dashboard/<path:id>')
+    api.add_resource(DashboardDescriptionAPI,
+                     '/dashboard/<path:id>/description')
+    api.add_resource(DashboardTagAPI,
+                     '/dashboard/<path:id>/tag/<tag>')
     app.register_blueprint(api_bp)
 
+    if app.config.get('SWAGGER_ENABLED'):
+        Swagger(app, template_file=os.path.join(ROOT_DIR, app.config.get('SWAGGER_TEMPLATE_PATH')), parse=True)
     return app
